@@ -1,6 +1,6 @@
 
 '''
-File: fibonacci_heap.java
+File: fibonacci_heap_mod.py
 Author: Keith Schwarz (htiek@cs.stanford.edu)
 Ported to Python by Dan Stromberg (strombrg@gmail.com)
 
@@ -172,6 +172,9 @@ def merge(one, two):
 class Entry(object):
     # pylint: disable=too-many-instance-attributes
     '''Hold an entry in the heap'''
+
+    __slots__ = ['m_degree', 'm_is_marked', 'm_parent', 'm_child', 'm_next', 'm_prev', 'm_elem', 'm_priority']
+
     def __init__(self, elem, priority):
         # Number of children
         self.m_degree = 0
@@ -328,7 +331,7 @@ class Fibonacci_heap(object):
     def min(self):
         '''
         Returns an Entry object corresponding to the minimum element of the
-        Fibonacci heap, throwing a NoSuchElementException if the heap is
+        Fibonacci heap, raising an IndexError if the heap is
         empty.
 
         @return The smallest element of the heap.
@@ -513,17 +516,17 @@ class Fibonacci_heap(object):
     def decrease_key(self, entry, new_priority):
         '''
         Decreases the key of the specified element to the new priority.  If the
-        new priority is greater than the old priority, this function throws an
-        IllegalArgumentException.  The new priority must be a finite double,
+        new priority is greater than the old priority, this function raises an
+        ValueError.  The new priority must be a finite double,
         so you cannot set the priority to be NaN, or +/- infinity.  Doing
-        so also throws an IllegalArgumentException.
+        so also raises an ValueError.
 
         It is assumed that the entry belongs in this heap.  For efficiency
         reasons, this is not checked at runtime.
 
         @param entry The element whose priority should be decreased.
         @param newPriority The new priority to associate with this entry.
-        @throws IllegalArgumentException If the new priority exceeds the old
+        @throws ValueError If the new priority exceeds the old
                 priority, or if the argument is not a finite double.
         '''
         self._check_priority(new_priority)
@@ -558,7 +561,7 @@ class Fibonacci_heap(object):
         @param priority The user's specified priority.
         @throws ValueError if it is not valid.
         '''
-        if math.isnan(priority):
+        if math.isnan(priority) or math.isinf(priority):
             raise ValueError("Priority {} is invalid.".format(priority))
 
     def decrease_key_unchecked(self, entry, priority):
@@ -601,7 +604,8 @@ class Fibonacci_heap(object):
             return
 
         # Rewire the node's siblings around it, if it has any siblings.
-        if entry.m_next != entry:
+        # DRS added these two id()'s Oct 26, 2014
+        if id(entry.m_next) != id(entry):
             # Has siblings
             entry.m_next.m_prev = entry.m_prev
             entry.m_prev.m_next = entry.m_next
@@ -609,8 +613,9 @@ class Fibonacci_heap(object):
         # If the node is the one identified by its parent as its child,
         # we need to rewrite that pointer to point to some arbitrary other
         # child.
-        if entry.m_parent.m_child == entry:
-            if entry.m_next != entry:
+        # DRS added these four id()'s Oct 26, 2014
+        if id(entry.m_parent.m_child) == id(entry):
+            if id(entry.m_next) != id(entry):
                 # If there are any other children, pick one of them arbitrarily.
                 entry.m_parent.m_child = entry.m_next
             else:
